#!/bin/bash

screen -X -S linien-server quit
bash linien_start_ethernet_blinking.sh